@@ -23,7 +23,7 @@ _base_object_storage_url = os.environ.get('base_minio_url', "api.minio.data.stor
 bucket_name = os.environ.get('bucketname', 'dataplatform')
 
 class Base:
-    def __init__(self, token=None, verbose=True, dataplatform_api_uri=_base_discovery_api, object_storage_uri=_base_object_storage_url, object_storage_secue=None):
+    def __init__(self, token=None, verbose=True, dataplatform_api_uri=_base_discovery_api, object_storage_uri=_base_object_storage_url, object_storage_secue=None, apikey=None):
         """_summary_
 
         Args:
@@ -49,22 +49,27 @@ class Base:
         self._base_discovery_api = base_discovery_api
         self._discovery_api = f"{base_discovery_api}/api/v2"
         
-        if token is None:
+        if (token is None) and (apikey is None):
             print(f"Please get token from {self._base_discovery_api.replace('api.','')}")
             token = input("Your Token : ")
             if defind_clear_output:
                 time.sleep(2)
                 clear_output()
-        if token in [None, '']:
+        if (token in [None, '']) and apikey == None:
             raise Exception('Please enter your token from discovery')
         self._jwt_header = {
             'Authorization': f'Bearer {token}'
         }
+        if apikey != None:
+            self._jwt_header = {
+                'Authorization': f'Api-Key {apikey}'
+            }
         _res = requests.get(f"{base_discovery_api}/api/v2/account/me/", headers=self._jwt_header)
         if _res.status_code != 200:
             txt = _res.json() if _res.status_code < 500 else " "
             raise Exception(f"Can not connect to DataPlatform, {txt}")
         self.token = token
+        self.apikey = apikey
         self._tmp_path = 'dsm.tmp'
         os.makedirs(self._tmp_path, exist_ok=True)
         _res = requests.get(f"{base_discovery_api}/api/minio/minio-user/me/", headers=self._jwt_header)
