@@ -2,6 +2,7 @@ from clickhouse_driver import Client
 from .utils.clickhouse import create_table, insert_ddf, insert_df, drop_table
 import pandas as pd
 import dask.dataframe as dd
+from .utils import check, clickhouse
 
 class ClickHouse:
     
@@ -144,4 +145,13 @@ class ClickHouse:
         """
         if tableName is None:
             raise Exception(f"plese input `tableName` str but got {type(tableName)}")
-        return drop_table(client=self._client, table_name=tableName, verbose=self._verbose)
\ No newline at end of file
+        return drop_table(client=self._client, table_name=tableName, verbose=self._verbose)
+    
+    def truncateTable(self, tableName=None):
+        """_summary_
+
+        Args:
+            tableName (_type_, optional): _description_. Defaults to None.
+        """
+        check.check_type(variable=tableName, variableName="tableName", dtype=str)
+        return clickhouse.truncate(client=self._client, table_name=tableName)
\ No newline at end of file
