@@ -4,6 +4,21 @@ from .utils.requests import check_http_status_code
 
 class GenerateDatadict(Base):
     def generate_datadict(self, name=None, directory_id=None, file_ids=None):
+        """_summary_
+
+        Args:
+            name (_type_, optional): _description_. Defaults to None.
+            directory_id (_type_, optional): _description_. Defaults to None.
+            file_ids (_type_, optional): _description_. Defaults to None.
+
+        Raises:
+            Exception: _description_
+            Exception: _description_
+            Exception: _description_
+
+        Returns:
+            _type_: _description_
+        """
         if name == None or type(name) != str:
             raise Exception(f"Please input data `name`=<str>, but got {type(name)}")
         name = name.replace('.','')
