@@ -313,16 +313,19 @@ class DataNode(DatasetManager):
             data = r.json()
             _database = DatabaseManagement(
                 token=self.token, 
+                apikey=self.apikey, 
                 dataplatform_api_uri=self._base_discovery_api,
                 object_storage_uri=self._base_minio_url,
             )
             database_id = data['database']
             database_meta, schema = _database.get_database_schema(database_id=database_id)
             
+            where_condition = extra_param.get('where_condition', '')
+
             exec(f"""
 {schema}
 from sqlalchemy import sql
-{data['query']}
+{data['query']+where_condition}
             """, globals())
             
             # to reorder metadata for dask
@@ -443,6 +446,7 @@ from sqlalchemy import sql
             'key': append_slash(meta['s3_key'])
         })
         _f_type = meta['type']['name']
+        
         if _f_type == "listDataNode":
             
             ddf_current = listDatanode.get_list_datanode(
